@@ -52,6 +52,18 @@ headers = {
     "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 11_2_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/88.0.4324.182 Safari/537.36 Edg/88.0.705.81"
 }
 
+# 登录检查；
+def auth_check(func):
+    def wrapper(*args, **kwargs):
+        url = 'https://api.qimai.cn/account/userinfo'
+        res = session.get(url, headers=headers)
+        if len(res.json()['userinfo']['username']) > 0:
+            func()
+        else:
+            print('尚未使用"Sing_Qimai"类登录七麦数据')
+            exit()
+    return wrapper
+
 # 钉钉推送；
 class DingDing_Push:
     """
@@ -85,6 +97,7 @@ class DingDing_Push:
         }
         payload = json.dumps(payload)
         res = requests.post(self.push_url, data=payload, headers=self.headers)
+        return res.json()
 
     def app_args_markdown_push(self):
         """
@@ -100,6 +113,7 @@ class DingDing_Push:
         }
         payload = json.dumps(payload)
         res = requests.post(self.push_url, data=payload, headers=self.headers)
+        return res.json()
 
     def app_args_text_push(self):
         payload = {
@@ -110,6 +124,7 @@ class DingDing_Push:
         }
         payload = json.dumps(payload)
         res = requests.post(self.push_url, data=payload, headers=self.headers)
+        return res.json()
 
 # 自动登录；
 class Sing_Qimai:
@@ -486,14 +501,13 @@ class Qimai_Diy_Var:
     """
         * 便于其他类继承的通用参数区：
     """
-    def __init__(self, country='cn', rank_type='all', version='ios12', device='iphone', brand='all', status=6, genre_type=36, lost_sort='out_time'):
+    def __init__(self, country='cn', rank_type='all', version='ios12', device='iphone', status=6, genre_type=36, lost_sort='out_time'):
         """
             * 类参数区：
             :param country: 国家/地区：默认中国
             :param rank_type: 榜单类型：默认全部榜单
             :param version: 系统版本：默认iOS 12
             :param device: 设备类型：默认iPhone
-            :param brand: 价格类型：默认全部，其他可选例如免费、付费、畅销
             :param status:
             :param genre_type: 榜单类型，默认全部，其他可选输入榜单对应榜单id即可
         """
@@ -501,7 +515,6 @@ class Qimai_Diy_Var:
         self.rank_type = rank_type
         self.version = version
         self.device = device
-        self.brand = brand
         self.status = status
         self.genre_type = genre_type
         self.lost_sort = lost_sort
@@ -569,6 +582,36 @@ class Get_App_Appinfo(Qimai_Diy_Var):
         self.app_version_data = res.json()
         return self.app_version_data
 
+    def get_version_info(self, start_date='', end_date=''):
+        """
+            * 获取App的版本信息：
+            * 可设定时间段，默认全部；
+            * 返回版本的版本号，版本时间等参数
+        """
+        self.get_version(start_date, end_date)
+        if len(self.app_version_data['version']) >= 2:
+            now_version_num = self.app_version_data['version'][0]['version']  # 当前版本号
+            now_version_time = self.app_version_data['version'][0]['release_time']  # 当前版本号时间
+            now_title = self.app_version_data['version'][0]['app_name']  # 当前版本App名称
+            now_subtitle = self.app_version_data['version'][0]['subtitle']  # 当前版本副标题
+            pre_version_num = self.app_version_data['version'][1]['version']
+            pre_version_time = self.app_version_data['version'][1]['release_time']
+            pre_title = self.app_version_data['version'][1]['app_name']
+            pre_subtitle = self.app_version_data['version'][1]['subtitle']
+
+            return [now_version_num, now_version_time, now_title, now_subtitle, pre_version_num, pre_version_time, pre_title, pre_subtitle]
+        else:  # 不大于等于2则小于2，没有多的版本；
+            now_version_num = self.app_version_data['version'][0]['version']  # 当前版本号
+            now_version_time = self.app_version_data['version'][0]['release_time']  # 当前版本号时间
+            now_title = self.app_version_data['version'][0]['app_name']  # 当前版本App名称
+            now_subtitle = self.app_version_data['version'][0]['subtitle']  # 当前版本副标题
+            pre_version_num = ''
+            pre_version_time = ''
+            pre_title = ''
+            pre_subtitle = ''
+
+            return [now_version_num, now_version_time, now_title, now_subtitle, pre_version_num, pre_version_time, pre_title, pre_subtitle]
+
     def get_baseinfo_parameter(self, user_type_name='支持网站'):
         """
             * 获取baseinfo接口下详细参数值，自行指定获取哪个：
@@ -589,9 +632,10 @@ class Get_App_Rank(Qimai_Diy_Var):
         * 根据AppID及对应时间，获取产品榜单数值；
         * 可获取子分类榜单；
         day: 计量时间类型：默认按天，其他可选按分钟、小时\n
-        rankType: 获取排名类型：默认每日排名，其他可选最高排名、全部排名
+        rankType: 获取排名类型：默认每日排名，其他可选最高排名、全部排名\n
+        brand: 价格类型：默认全部，其他可选例如免费、付费、畅销
     """
-    def __init__(self, appid, start_date, end_date, day=1, rankType='day', appRankShow=1, subclass='all', simple=1, rankEchartType=1):
+    def __init__(self, appid, start_date, end_date, day=1, rankType='day', brand='all', appRankShow=1, subclass='all', simple=1, rankEchartType=1):
         Qimai_Diy_Var.__init__(self)
         self.appid = appid
         self.start_date = start_date
@@ -602,6 +646,7 @@ class Get_App_Rank(Qimai_Diy_Var):
         self.subclass = subclass
         self.simple = simple
         self.rankEchartType = rankEchartType
+        self.brand = brand
 
     def get_rank_data(self):
         """
@@ -698,12 +743,12 @@ class Get_Keyword_Info(Qimai_Diy_Var):
         self.end_date = end_date
         self.search_type= search_type
 
-    def get_keyword_search(self):
+    def get_keyword_search(self, page_num=1):
         """
             * 获取关键词下产品信息(第一页)：
             * 默认搜索版本为iOS 12；
         """
-        url = 'https://api.qimai.cn/search/index?device=%s&country=%s&search=%s&date=%s&version=%s&search_type=%s&changeRateDate=&page=1&changeRateType=top10&sdate=%s&edate=%s&status=%s' %(self.device, self.country, self.keyword, self.start_date, self.version, self.search_type, self.start_date, self.end_date, self.status)
+        url = 'https://api.qimai.cn/search/index?device=%s&country=%s&search=%s&date=%s&version=%s&search_type=%s&changeRateDate=&changeRateType=top10&sdate=%s&edate=%s&status=%s&page=%s' %(self.device, self.country, self.keyword, self.start_date, self.version, self.search_type, self.start_date, self.end_date, self.status, page_num)
         headers = {
             'origin': 'https://www.qimai.cn',
             'referer': 'https://www.qimai.cn/',
@@ -713,7 +758,7 @@ class Get_Keyword_Info(Qimai_Diy_Var):
         self.keyword_search_index = res.json()
         return self.keyword_search_index
 
-    def get_keyword_search_more(self, max_index=1000000):
+    def get_keyword_search_list(self, max_index=1000000):
         """
             * 获取关键词下产品信息，带翻页：
             * 默认搜索版本为iOS 12；
@@ -742,7 +787,6 @@ class Get_Keyword_Info(Qimai_Diy_Var):
             * 包含指数、结果数、WordID等；
         """
         url = 'https://api.qimai.cn/search/getWordInfo?device=%s&country=%s&search=%s&version=%s&date=%s&search_type=%s&status=%s' %(self.device, self.country, self.keyword, self.version, self.start_date, self.search_type, self.status)
-        # url = 'https://api.qimai.cn/search/getWordInfo?device=%s&country=%s&search=%s&version=%s&date=%s&search_type=%s&edate=%s&status=%s' %(self.device, self.country, self.keyword, self.version, self.start_date, self.search_type, self.end_date, self.status)
         headers = {
             'origin': 'https://www.qimai.cn',
             'referer': 'https://www.qimai.cn/',
@@ -851,6 +895,17 @@ class Get_Keyword_Info(Qimai_Diy_Var):
                 break
         return self.keyword_extend_list
 
+    def get_keyword_extend_onePage(self, page_num=1, orderBy='', order=''):
+        """
+            * 关键词扩展助手接口：
+            :param page_num: 页码数，默认获取第一页；
+            :param orderBy: 相关度排序，例：desc
+            :param order: 搜索指数排序，例：desc
+        """
+        url = 'https://api.qimai.cn/trend/keywordExtend?keyword=%s&page=%s&orderBy=%s&order=%s' % (self.keyword, page_num, orderBy, order)
+        res = session.get(url, headers=headers)
+        return res.json()
+
     def get_top_to_df(self, top_num=100):
         """
             * 关键词搜索后的产品列表转换为dataframe格式；
@@ -1037,7 +1092,7 @@ class Get_App_Comment(Qimai_Diy_Var):
         * 举例①：获取App每天的新增评论数；
         * 举例②：获取App指定星级每天评论数据；
     """
-    def __init__(self, appid, start_date, end_date):
+    def __init__(self, appid, start_date=today_date-datetime.timedelta(days=29), end_date=today_date):
         Qimai_Diy_Var.__init__(self)
         self.appid = appid
         self.start_date = start_date
@@ -1053,6 +1108,18 @@ class Get_App_Comment(Qimai_Diy_Var):
         self.app_commentRateNum = res.json()
         return self.app_commentRateNum
 
+    def get_commentRateNum_add(self, typec='day'):
+        """
+            * 获取1-5星时间段内新增评论数；
+            :param typec: 评论计量时间单位：默认按天
+        """
+        self.get_commentRateNum(typec)
+        pinlun_num_list = []
+        for i in self.app_commentRateNum['rateInfo']:
+            pinlun_num_list.append(i['data'][0][1])  # 新增评论加进去
+
+        return np.sum(pinlun_num_list)
+
     def get_commentNum(self, delete=-1):
         """
             * 获取每日已删除未删除评论数量；
@@ -1115,7 +1182,7 @@ class Get_Clear_Rank_List(Qimai_Diy_Var):
         status_type: 清榜应用类型，默认全部，其他可选例如免费、付费\n
         clear_type: 清榜列表产品当前状态筛选，默认全部，其他可选清榜、已恢复
     """
-    def __init__(self, start_date, end_date, status_type=3, clear_type=1):
+    def __init__(self, start_date=today_date-datetime.timedelta(days=6), end_date=today_date, status_type=3, clear_type=1):
         Qimai_Diy_Var.__init__(self)
         self.start_date = start_date
         self.end_date = end_date
@@ -1139,17 +1206,28 @@ class Get_Clear_Rank_List(Qimai_Diy_Var):
                 break
         return self.clear_rank_list
 
+    def get_clear_rank_onePage(self, page_num=1):
+        """
+            * 获取时间段内清榜类目下产品相关信息：
+            * 从类中指定开始结束时间；
+            :param page_num: 页码数，默认获取第一页；
+        """
+        url = 'https://api.qimai.cn/rank/clear?1=&sdate=%s&edate=%s&page=%s&type=%s&genre=%s&status=%s' %(self.start_date, self.end_date, page_num, self.clear_type, self.genre_type, self.status_type)
+        res = session.get(url, headers=headers)
+        return res.json()
+
+
 # 获取清词列表相关数据；
 class Get_Clear_Keyword_List(Qimai_Diy_Var):
     """
-        * 获取清词列表相关数据；
+        * 获取清词列表相关数据(清词的产品多所以按日展示的)；
         * 举例①：获取当前清词列表所有清词产品相关数据；
         filter: 清词产品类型，默认过滤下架应用，其他可选不过滤\n
         search_word: 清词产品，可搜索产品名，默认不搜索\n
         sort_field: 其他排序规则，默认清词前关键词数量\n
         sort_type: 清词前关键词数量排序规则，默认降序\n
     """
-    def __init__(self, start_date, end_date, filter='offline', search_word='', export_type='rank_clear_words', sort_field='beforeClearNum', sort_type='desc'):
+    def __init__(self, start_date=today_date, end_date=today_date, filter='offline', search_word='', export_type='rank_clear_words', sort_field='beforeClearNum', sort_type='desc'):
         Qimai_Diy_Var.__init__(self)
         self.start_date = start_date
         self.end_date = end_date
@@ -1176,14 +1254,24 @@ class Get_Clear_Keyword_List(Qimai_Diy_Var):
                 break
         return self.clear_word_list
 
+    def get_clear_keyword_onePage(self, page_num=1):
+        """
+            * 获取时间段内清词列表产品相关信息：
+            * 从类中指定开始结束时间；
+            :param page_num: 页码数，默认获取第一页；
+        """
+        url = 'https://api.qimai.cn/rank/clearWords?edate=%s&page=%s&genre=%s&sdate=%s&filter=%s&export_type=%s&sort_field=%s&sort_type=%s&search=%s' %(self.end_date, page_num, self.genre_type, self.start_date, self.filter, self.export_type, self.sort_field, self.sort_type, self.search_word)
+        res = session.get(url, headers=headers)
+        return res.json()
+
 # 获取上架、下架产品列表相关数据；
 class Get_App_ON_Offline_List(Qimai_Diy_Var):
     """
-        * 获取上架、下架列表相关数据；
+        * 获取上架、下架列表相关数据(上下架的产品多所以按日展示的)；
         * 举例①：获取当前下架列表所有下架产品相关数据；
         option: 上架、下架监控排序，默认按近期最高排名
     """
-    def __init__(self, start_date, end_date, option=4, search_word=''):
+    def __init__(self, start_date=today_date, end_date=today_date, option=4, search_word=''):
         Qimai_Diy_Var.__init__(self)
         self.start_date = start_date
         self.end_date = end_date
@@ -1207,6 +1295,16 @@ class Get_App_ON_Offline_List(Qimai_Diy_Var):
                 break
         return self.app_offline_list
 
+    def get_app_offline_onePage(self, page_num=1):
+        """
+            * 获取时间段内下架列表产品相关信息：
+            * 从类中指定开始结束时间；
+            :param page_num: 页码数，默认获取第一页；
+        """
+        url = 'https://api.qimai.cn/rank/offline?date=%s_%s&country=%s&genre=%s&option=%s&search=%s&sdate=%s&edate=%s&page=%s' % (self.start_date, self.end_date, self.country, self.genre_type, self.option, self.search_word, self.start_date, self.end_date, page_num)
+        res = session.get(url, headers=headers)
+        return res.json()
+
     def get_app_release(self, is_preorder='all'):
         """
             * 获取时间段内上架列表产品相关信息：
@@ -1224,6 +1322,16 @@ class Get_App_ON_Offline_List(Qimai_Diy_Var):
                 break
         return self.app_online_list
 
+    def get_app_release_onePage(self, page_num=1, is_preorder='all'):
+        """
+            * 获取时间段内上架列表产品相关信息：
+            * 从类中指定开始结束时间；
+            :param page_num: 页码数，默认获取第一页；
+        """
+        url = 'https://api.qimai.cn/rank/release?date=%s_%s&country=%s&genre=%s&is_preorder=%s&search=%s&sdate=%s&edate=%s&page=%s' % (self.start_date, self.end_date, self.country, self.genre_type, is_preorder, self.search_word, self.start_date, self.end_date, page_num)
+        res = session.get(url, headers=headers)
+        return res.json()
+
 # 获取预订App列表；
 class Get_PreOrder_AppList(Qimai_Diy_Var):
     """
@@ -1254,6 +1362,18 @@ class Get_PreOrder_AppList(Qimai_Diy_Var):
                 break
         return self.preOrder_applist_list
 
+    def get_preOrder_applist_onePage(self, page_num=1):
+        """
+            * 获取时间段内预订App列表产品相关信息；
+            * 从类中指定开始结束时间；
+            :param page_num: 页码数，默认获取第一页；
+            preOrder_order - 预订排序规则，默认按照发布日期；\n
+            price_status - 预订产品价格筛选，默认全部，1为免费，0为付费，3为全部
+        """
+        url = 'https://api.qimai.cn/rank/preOrder?genre=%s&country=%s&order=%s&status=%s&page=%s' %(self.genre_type, self.country, self.preOrder_order, self.price_status, page_num)
+        res = session.get(url, headers=headers)
+        return res.json()
+
 # 获取产品被精品推荐及上热搜情况列表；
 class Get_App_Recommend(Qimai_Diy_Var):
     """
@@ -1344,7 +1464,7 @@ class Get_App_Status(Qimai_Diy_Var):
         page_num = 1
         while True:
             url = 'https://api.qimai.cn/app/appStatusList'
-            payload='appid=%s&country=%s&status=all&sdate=%s&edate=%s&page=1&order=%s&sort=%s' %(self.appid, self.country, self.start_date, self.end_date, self.app_status_order, self.app_status_sort)
+            payload='appid=%s&country=%s&status=all&sdate=%s&edate=%s&page=%s&order=%s&sort=%s' %(self.appid, self.country, self.start_date, self.end_date, page_num, self.app_status_order, self.app_status_sort)
             res = session.post(url, data=payload, headers=headers)
             self.app_status_list.append(res.json())
             page_num += 1
@@ -1352,17 +1472,26 @@ class Get_App_Status(Qimai_Diy_Var):
                 break
         return self.app_status_list
 
+    def get_all_appStatusList_onePage(self, page_num=1):
+        """
+            * 获取所有状态信息：
+            :param page_num: 页码数，默认获取第一页；
+        """
+        url = 'https://api.qimai.cn/app/appStatusList'
+        payload='appid=%s&country=%s&status=all&sdate=%s&edate=%s&page=%s&order=%s&sort=%s' %(self.appid, self.country, self.start_date, self.end_date, page_num, self.app_status_order, self.app_status_sort)
+        res = session.post(url, data=payload, headers=headers)
+        return res.json()
+
     def get_status_appStatusList(self, app_status_str='all'):
         """
             * 获取指定状态的所有状态信息：
             :param app_status_str: App状态，默认全部；
-
         """
         self.app_status_list = []
         page_num = 1
         while True:
             url = 'https://api.qimai.cn/app/appStatusList'
-            payload='appid=%s&country=%s&status=%s&sdate=%s&edate=%s&page=1&order=%s&sort=%s' %(self.appid, self.country, app_status_str, self.start_date, self.end_date, self.app_status_order, self.app_status_sort)
+            payload='appid=%s&country=%s&status=%s&sdate=%s&edate=%s&page=%s&order=%s&sort=%s' %(self.appid, self.country, app_status_str, self.start_date, self.end_date, page_num, self.app_status_order, self.app_status_sort)
             headers = {
                 'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.125 Safari/537.36',
                 'content-type': 'application/x-www-form-urlencoded; charset=UTF-8'
@@ -1374,11 +1503,26 @@ class Get_App_Status(Qimai_Diy_Var):
                 break
         return self.app_status_list
 
-    def get_new_status_info(self):
+    def get_status_appStatusList_onePage(self, page_num=1, app_status_str='all'):
+        """
+            * 获取指定状态的所有状态信息：
+            :param page_num: 页码数，默认获取第一页；
+            :param app_status_str: App状态，默认全部；
+        """
+        url = 'https://api.qimai.cn/app/appStatusList'
+        payload='appid=%s&country=%s&status=%s&sdate=%s&edate=%s&page=%s&order=%s&sort=%s' %(self.appid, self.country, app_status_str, self.start_date, self.end_date, page_num, self.app_status_order, self.app_status_sort)
+        headers = {
+            'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.125 Safari/537.36',
+            'content-type': 'application/x-www-form-urlencoded; charset=UTF-8'
+        }
+        res = session.post(url, data=payload, headers=headers)
+        return res.json()
+
+    def get_new_status_info(self, app_status_str='all'):
         """
             * 获取指定状态最新的状态时间：
         """
-        self.get_status_appStatusList()
+        self.get_status_appStatusList(app_status_str)
         for status_list in self.app_status_list:
             if status_list['msg'] == '成功':
                 if len(status_list['data']) > 0:
@@ -1388,11 +1532,11 @@ class Get_App_Status(Qimai_Diy_Var):
                     return ''
             return ''
 
-    def get_old_status_info(self):
+    def get_old_status_info(self, app_status_str='all'):
         """
             * 获取指定状态最老的状态时间：
         """
-        self.get_status_appStatusList()
+        self.get_status_appStatusList(app_status_str)
         for status_list in self.app_status_list:
             if status_list['msg'] == '成功':
                 if len(status_list['data']) > 0:
@@ -1442,19 +1586,31 @@ class Get_Keyword_HintsRank(Qimai_Diy_Var):
                 break
         return self.keyword_hintsRank_list
 
+    def get_hints_rank_onePage(self, page_num=1):
+        """
+            * 获取搜索指数排行榜；
+            :param page_num: 页码数，默认获取第一页；
+        """
+        url = 'https://api.qimai.cn/trend/keywordHintsRank?date=%s&page=%s&change_inc=%s&minResult=%s&maxResult=%s&genre=%s&minHints=%s&maxHints=%s&device=%s&country=%s&minPopular=%s&maxPopular=%s' %(self.run_time, page_num, self.change_inc, self.minResult, self.maxResult, self.genre_type, self.minHints, self.maxHints, self.device, self.country, self.minPopular, self.maxPopular)
+        res = session.get(url, headers=headers)
+        return res.json()
+
 # 封装关键词落词、新进、上升、下降列表接口；
-class Get_Keyword_LoseNewDownUp_List(Get_Clear_Keyword_List):
+class Get_Keyword_LoseNewDownUp_List(Qimai_Diy_Var):
     """
         * 获取关键词下落榜、新进、上升、下降产品列表相关数据；
         * 举例①：获取当前词落榜产品基本信息，落榜前排名等相关数据；
         top_history: 历史排名，默认全部，可选进入过T10
     """
-    def __init__(self, keyword, start_date=today_date, end_date=today_date, top_history='all'):
-        super(Get_Keyword_LoseNewDownUp_List, self).__init__(start_date, end_date)
+    def __init__(self, keyword, start_date=today_date, end_date=today_date, top_history='all', filter='offline', search_word='', sort_type='desc'):
+        Qimai_Diy_Var.__init__(self)
         self.keyword = keyword
         self.start_date = start_date
         self.end_date = end_date
         self.top_history = top_history
+        self.filter = filter
+        self.search_word = search_word
+        self.sort_type = sort_type
 
     def get_lostApp_list(self):
         """
@@ -1472,20 +1628,20 @@ class Get_Keyword_LoseNewDownUp_List(Get_Clear_Keyword_List):
                 break
         return self.keyword_lostApp_list
 
-    def get_lostApp_onePage(self):
+    def get_lostApp_onePage(self, page_num=1):
         """
             * 获取词下落榜App的数据-第一页：
         """
-        url = 'https://api.qimai.cn/search/searchPageExtend?history=%s&version=%s&device=%s&filter=%s&word=%s&country=%s&date=oneMonth&sort=out_time&sort_type=%s&type=out&sdate=%s&edate=%s&page=1' % (self.top_history, self.version, self.device, self.filter, self.keyword, self.country, self.sort_type, self.start_date, self.end_date)
+        url = 'https://api.qimai.cn/search/searchPageExtend?history=%s&version=%s&device=%s&filter=%s&word=%s&country=%s&date=oneMonth&sort=out_time&sort_type=%s&type=out&sdate=%s&edate=%s&page=%s' % (self.top_history, self.version, self.device, self.filter, self.keyword, self.country, self.sort_type, self.start_date, self.end_date, page_num)
         res = session.get(url, headers=headers)
         self.lostApp_onePage_data = res.json()
         return self.lostApp_onePage_data
 
-    def get_lostApp_num(self):
+    def get_lostApp_num(self, page_num=1):
         """
             * 获取词下落榜App的数量：
         """
-        self.get_lostApp_onePage()
+        self.get_lostApp_onePage(page_num)
         return self.lostApp_onePage_data['total_num']
 
     def get_newApp_list(self):
@@ -1504,20 +1660,20 @@ class Get_Keyword_LoseNewDownUp_List(Get_Clear_Keyword_List):
                 break
         return self.keyword_newApp_list
 
-    def get_newApp_onePage(self):
+    def get_newApp_onePage(self, page_num=1):
         """
             * 获取词下新进App的数据-第一页：
         """
-        url = 'https://api.qimai.cn/search/searchPageExtend?history=%s&version=%s&device=%s&filter=%s&word=%s&country=%s&date=oneMonth&sort=new_time&sort_type=%s&type=new&sdate=%s&edate=%s&page=1' % (self.top_history, self.version, self.device, self.filter, self.keyword, self.country, self.sort_type, self.start_date, self.end_date)
+        url = 'https://api.qimai.cn/search/searchPageExtend?history=%s&version=%s&device=%s&filter=%s&word=%s&country=%s&date=oneMonth&sort=new_time&sort_type=%s&type=new&sdate=%s&edate=%s&page=%s' % (self.top_history, self.version, self.device, self.filter, self.keyword, self.country, self.sort_type, self.start_date, self.end_date, page_num)
         res = session.get(url, headers=headers)
         self.newApp_onePage_data = res.json()
         return self.newApp_onePage_data
 
-    def get_newApp_num(self):
+    def get_newApp_num(self, page_num=1):
         """
             * 获取词下新进App的数量：
         """
-        self.get_newApp_onePage()
+        self.get_newApp_onePage(page_num)
         return self.newApp_onePage_data['total_num']
 
     def get_rankDown_list(self):
@@ -1536,20 +1692,20 @@ class Get_Keyword_LoseNewDownUp_List(Get_Clear_Keyword_List):
                 break
         return self.keyword_rankDown_list
 
-    def get_rankDown_onePage(self):
+    def get_rankDown_onePage(self, page_num=1):
         """
             * 获取词下排名下降较快App的数据-第一页：
         """
-        url = 'https://api.qimai.cn/search/searchPageExtend?history=%s&version=%s&device=%s&filter=%s&word=%s&country=%s&date=oneMonth&sort=down_rank&sort_type=%s&type=down&sdate=%s&edate=%s&page=1' % (self.top_history, self.version, self.device, self.filter, self.keyword, self.country, self.sort_type, self.start_date, self.end_date)
+        url = 'https://api.qimai.cn/search/searchPageExtend?history=%s&version=%s&device=%s&filter=%s&word=%s&country=%s&date=oneMonth&sort=down_rank&sort_type=%s&type=down&sdate=%s&edate=%s&page=%s' % (self.top_history, self.version, self.device, self.filter, self.keyword, self.country, self.sort_type, self.start_date, self.end_date, page_num)
         res = session.get(url, headers=headers)
         self.rankDown_onePage_data = res.json()
         return self.rankDown_onePage_data
 
-    def get_rankDown_num(self):
+    def get_rankDown_num(self, page_num=1):
         """
             * 获取词下排名下降较快App的数量：
         """
-        self.get_rankDown_onePage()
+        self.get_rankDown_onePage(page_num)
         return self.rankDown_onePage_data['total_num']
 
     def get_rankGoUp_list(self):
@@ -1568,20 +1724,20 @@ class Get_Keyword_LoseNewDownUp_List(Get_Clear_Keyword_List):
                 break
         return self.keyword_rankUp_list
 
-    def get_rankGoUp_onePage(self):
+    def get_rankGoUp_onePage(self, page_num=1):
         """
              * 获取词下排名上升较快App的数据-第一页：
         """
-        url = 'https://api.qimai.cn/search/searchPageExtend?history=%s&version=%s&device=%s&filter=%s&word=%s&country=%s&date=oneMonth&sort=up_rank&sort_type=%s&type=up&sdate=%s&edate=%s&page=1' % (self.top_history, self.version, self.device, self.filter, self.keyword, self.country, self.sort_type, self.start_date, self.end_date)
+        url = 'https://api.qimai.cn/search/searchPageExtend?history=%s&version=%s&device=%s&filter=%s&word=%s&country=%s&date=oneMonth&sort=up_rank&sort_type=%s&type=up&sdate=%s&edate=%s&page=%s' % (self.top_history, self.version, self.device, self.filter, self.keyword, self.country, self.sort_type, self.start_date, self.end_date, page_num)
         res = session.get(url, headers=headers)
         self.rankGoUp_onePage_data = res.json()
         return self.rankGoUp_onePage_data
 
-    def get_rankGoUp_num(self):
+    def get_rankGoUp_num(self, page_num=1):
         """
              * 获取词下排名上升较快App的数量：
         """
-        self.get_rankGoUp_onePage()
+        self.get_rankGoUp_onePage(page_num)
         return self.rankGoUp_onePage_data['total_num']
 
     def get_t10App_list(self):
@@ -1600,6 +1756,16 @@ class Get_Keyword_LoseNewDownUp_List(Get_Clear_Keyword_List):
                 break
         return self.keyword_t10App_list
 
+    def get_t10App_list_onePage(self, page_num=1):
+        """
+            * 获取关键词下T10产品监控数据；
+            :param page_num: 页码数，默认获取第一页；
+        """
+        url = 'https://api.qimai.cn/search/rankHistory?version=%s&device=%s&word=%s&page=%s&country=%s&sdate=%s&edate=%s' % (self.version, self.device, self.keyword, page_num, self.country, self.start_date, self.end_date)
+        res = session.get(url, headers=headers)
+        return res.json()
+
+
 # 获取免费、付费、畅销榜单产品列表；
 class Get_FreePaidGross_RankList(Qimai_Diy_Var):
     """
@@ -1611,11 +1777,11 @@ class Get_FreePaidGross_RankList(Qimai_Diy_Var):
         self.snapshot = snapshot
         self.run_time = run_time
 
-    def get_updateTime_data(self):
+    def get_updateTime_data(self, page_num=1):
         """
             * 获取榜单快照更新时间列表；
         """
-        url = 'https://api.qimai.cn/rank/indexSnapshot?brand=%s&device=%s&country=%s&genre=%s&date=%s&page=1&is_rank_index=1' %(self.brand, self.device, self.country, self.genre_type, self.run_time)
+        url = 'https://api.qimai.cn/rank/indexSnapshot?brand=%s&device=%s&country=%s&genre=%s&date=%s&page=%s&is_rank_index=1' %(self.brand, self.device, self.country, self.genre_type, self.run_time, page_num)
         res = session.get(url, headers=headers)
         self.rank_update_data = res.json()
         return self.rank_update_data
@@ -1638,11 +1804,11 @@ class Get_FreePaidGross_RankList(Qimai_Diy_Var):
                 break
         return self.app_freeRank_list
 
-    def get_freeRank_onePage(self):
+    def get_freeRank_onePage(self, page_num=1):
         """
             * 获取免费榜产品列表-第一页：
         """
-        url = 'https://api.qimai.cn/rank/index?brand=free&device=%s&country=%s&genre=%s&date=%s&snapshot=%s&is_rank_index=1&page=1' % (self.device, self.country, self.genre_type, self.run_time, self.snapshot)
+        url = 'https://api.qimai.cn/rank/index?brand=free&device=%s&country=%s&genre=%s&date=%s&snapshot=%s&is_rank_index=1&page=%s' % (self.device, self.country, self.genre_type, self.run_time, self.snapshot, page_num)
         res = session.get(url, headers=headers)
         return res.json()
 
@@ -1664,11 +1830,11 @@ class Get_FreePaidGross_RankList(Qimai_Diy_Var):
                 break
         return self.app_paidRank_list
 
-    def get_paidRank_onePage(self):
+    def get_paidRank_onePage(self, page_num=1):
         """
             * 获取付费榜产品列表-第一页：
         """
-        url = 'https://api.qimai.cn/rank/index?brand=paid&device=%s&country=%s&genre=%s&date=%s&snapshot=%s&is_rank_index=1&page=1' % (self.device, self.country, self.genre_type, self.run_time, self.snapshot)
+        url = 'https://api.qimai.cn/rank/index?brand=paid&device=%s&country=%s&genre=%s&date=%s&snapshot=%s&is_rank_index=1&page=%s' % (self.device, self.country, self.genre_type, self.run_time, self.snapshot, page_num)
         res = session.get(url, headers=headers)
         return res.json()
 
@@ -1690,11 +1856,11 @@ class Get_FreePaidGross_RankList(Qimai_Diy_Var):
                 break
         return self.app_grossRank_list
 
-    def get_grossRank_onePage(self):
+    def get_grossRank_onePage(self, page_num=1):
         """
             * 获取畅销榜产品列表-第一页：
         """
-        url = 'https://api.qimai.cn/rank/index?brand=grossing&device=%s&country=%s&genre=%s&date=%s&snapshot=%s&is_rank_index=1&page=1' % (self.device, self.country, self.genre_type, self.run_time, self.snapshot)
+        url = 'https://api.qimai.cn/rank/index?brand=grossing&device=%s&country=%s&genre=%s&date=%s&snapshot=%s&is_rank_index=1&page=%s' % (self.device, self.country, self.genre_type, self.run_time, self.snapshot, page_num)
         res = session.get(url, headers=headers)
         return res.json()
 
@@ -1704,7 +1870,7 @@ class Get_AppDownRevenue_Data(Qimai_Diy_Var):
         * 获取产品预估下载量及预估收入数据；
         * 举例①：获取产品在某时间段内每日预估下载量数据；
     """
-    def __init__(self, appid, start_date=today_date-datetime.timedelta(days=7), end_date=today_date-one_day):
+    def __init__(self, appid, start_date=today_date-datetime.timedelta(days=6), end_date=today_date-one_day):
         Qimai_Diy_Var.__init__(self)
         self.appid = appid
         self.start_date = start_date
@@ -1735,7 +1901,7 @@ class Get_HotSearch_Data(Qimai_Diy_Var):
         * 举例①：获取近期上榜的关键词数量指数区间分析；
         * 举例②：获取热搜更新时间分布数据；
     """
-    def __init__(self, start_date, end_date):
+    def __init__(self, start_date=today_date-datetime.timedelta(days=6), end_date=today_date):
         Qimai_Diy_Var.__init__(self)
         self.start_date = start_date
         self.end_date = end_date
@@ -1782,10 +1948,12 @@ class Get_Rank_UpDown_List(Qimai_Diy_Var):
     """
         * 获取榜单上升下降较快的产品；
         * 举例①：获取今日下降较快产品；
+        brand: 价格类型：默认全部，其他可选例如免费、付费、畅销
     """
-    def __init__(self, upDown_type='one'):
+    def __init__(self, upDown_type='one', brand='all'):
         Qimai_Diy_Var.__init__(self)
         self.upDown_type = upDown_type
+        self.brand = brand
 
     def get_up_rank(self, max_index=1000000):
         """
@@ -1806,6 +1974,15 @@ class Get_Rank_UpDown_List(Qimai_Diy_Var):
                 break
         return self.up_rank_list
 
+    def get_up_rank_onePgae(self, page_num=1):
+        """
+            * 获取榜单上升较快的产品列表：
+            :param page_num: 页码数，默认获取第一页；
+        """
+        url = 'https://api.qimai.cn/rank/float?float=up&genre=%s&device=%s&type=%s&brand=%s&country=%s&page=%s' %(self.genre_type, self.device, self.upDown_type, self.brand, self.country, page_num)
+        res = session.get(url, headers=headers)
+        return res.json()
+
     def get_down_rank(self, max_index=1000000):
         """
             * 获取榜单下降较快的产品列表：
@@ -1825,6 +2002,15 @@ class Get_Rank_UpDown_List(Qimai_Diy_Var):
                 break
         return self.down_rank_list
 
+    def get_down_rank_onePage(self, page_num=1):
+        """
+            * 获取榜单下降较快的产品列表：
+            :param page_num: 页码数，默认获取第一页；
+        """
+        url = 'https://api.qimai.cn/rank/float?float=down&genre=%s&device=%s&type=%s&brand=%s&country=%s&page=%s' %(self.genre_type, self.device, self.upDown_type, self.brand, self.country, page_num)
+        res = session.get(url, headers=headers)
+        return res.json()
+
 # 获取各类覆盖排行榜；
 class Get_Cover_Rank(Qimai_Diy_Var):
     """
@@ -1856,6 +2042,17 @@ class Get_Cover_Rank(Qimai_Diy_Var):
                 break
         return self.keyword_cover_list
 
+    def get_keyword_cover_onePage(self, page_num=1, keyword_type='all', match_hints='0'):
+        """
+            * 获取产品关键词覆盖排行榜产品列表：
+            :param page_num: 页码数，默认获取第一页；
+            :param keyword_type: 获取类型限制，例：全部/T3/T10；
+            :param match_hints: 获取指数限制，例：0/4605；
+        """
+        url = 'https://api.qimai.cn/rank/keywordCoverRank?device=%s&country=%s&genre=%s&type=%s&isinc=0&hints=%s&page=%s' %(self.device, self.country, self.genre_type, keyword_type, match_hints, page_num)
+        res = session.get(url, headers=headers)
+        return res.json()
+
     def get_grow_cover(self, max_index=1000000, keyword_type='all', match_hints='0'):
         """
             * 获取产品关键词增长榜产品列表：
@@ -1877,6 +2074,17 @@ class Get_Cover_Rank(Qimai_Diy_Var):
                 break
         return self.grow_cover_list
 
+    def get_grow_cover_onePage(self, page_num=1, keyword_type='all', match_hints='0'):
+        """
+            * 获取产品关键词增长榜产品列表：
+            :param page_num: 页码数，默认获取第一页；
+            :param keyword_type: 获取类型限制，例：全部/T3/T10；
+            :param match_hints: 获取指数限制，例：0/4605；
+        """
+        url = 'https://api.qimai.cn/rank/keywordCoverRank?device=%s&country=%s&genre=%s&type=%s&isinc=1&hints=%s&page=%s' %(self.device, self.country, self.genre_type, keyword_type, match_hints, page_num)
+        res = session.get(url, headers=headers)
+        return res.json()
+
     def get_topic_cover(self, max_page=1000000):
         """
             * 获取专题关键词覆盖榜列表：
@@ -1894,6 +2102,15 @@ class Get_Cover_Rank(Qimai_Diy_Var):
                 break
         return self.topic_cover_list
 
+    def get_topic_cover_onePage(self, page_num=1):
+        """
+            * 获取专题关键词覆盖榜列表：
+            :param page_num: 页码数，默认获取第一页；
+        """
+        url = 'https://api.qimai.cn/search/searchExtendCover?kind=editorialItem&page=%s&device=%s&country=%s&genre=%s&search=%s' %(page_num, self.device, self.country, self.genre_type, self.search_word)
+        res = session.get(url, headers=headers)
+        return res.json()
+
     def get_develpoer_cover(self, max_index=1000000):
         """
             * 获取开发者关键词覆盖榜列表：
@@ -1913,6 +2130,15 @@ class Get_Cover_Rank(Qimai_Diy_Var):
                 break
         return self.develpoer_cover_list
 
+    def get_develpoer_cover_onePage(self, page_num=1):
+        """
+            * 获取开发者关键词覆盖榜列表：
+            :param page_num: 页码数，默认获取第一页；
+        """
+        url = 'https://api.qimai.cn/search/searchExtendCover?kind=softwareDeveloper&page=%s&device=%s&country=%s&genre=%s&search=%s' %(page_num, self.device, self.country, self.genre_type, self.search_word)
+        res = session.get(url, headers=headers)
+        return res.json()
+
     def get_purchase_cover(self, max_index=1000000):
         """
             * 获取内购关键词覆盖榜列表：
@@ -1932,3 +2158,11 @@ class Get_Cover_Rank(Qimai_Diy_Var):
                 break
         return self.purchase_cover_list
 
+    def get_purchase_cover_onePage(self, page_num=1):
+        """
+            * 获取内购关键词覆盖榜列表：
+            :param page_num: 页码数，默认获取第一页；
+        """
+        url = 'https://api.qimai.cn/search/searchExtendCover?kind=softwareAddOn&page=%s&device=%s&country=%s&genre=%s&search=%s' %(page_num, self.device, self.country, self.genre_type, self.search_word)
+        res = session.get(url, headers=headers)
+        return res.json()
